@@ -1,13 +1,15 @@
 """
 UBXReader class.
 
-Reads and parses individual UBX or NMEA messages from any stream
+Reads and parses individual UBX, NMEA or RTCM3 messages from any stream
 which supports a read(n) -> bytes method.
 
-Returns both the raw binary data (as bytes) and the parsed data
-(as a UBXMessage or NMEAMessage object).
+NB: pyubx2 does not currently decode RTCM3 data.
 
-'protfilter' governs which protocols (NMEA and/or UBX) are processed
+Returns both the raw binary data (as bytes) and the parsed data
+(as a UBXMessage, NMEAMessage or stub RTCMMessage object).
+
+'protfilter' governs which protocols (NMEA, UBX or RTCM3) are processed
 'quitonerror' governs how errors are handled
 
 Created on 2 Oct 2020
@@ -19,8 +21,8 @@ Created on 2 Oct 2020
 
 from pynmeagps import NMEAReader
 import pynmeagps.exceptions as nme
-from pyubx2 import UBXMessage
-from pyubx2.ubxhelpers import calc_checksum, val2bytes, bytes2val
+from pyubx2 import UBXMessage, RTCMMessage
+from pyubx2.ubxhelpers import calc_checksum, val2bytes, bytes2val, calc_crc24q
 import pyubx2.ubxtypes_core as ubt
 import pyubx2.exceptions as ube
 
@@ -35,7 +37,7 @@ class UBXReader:
 
         :param datastream stream: input data stream
         :param int quitonerror: (kwarg) 0 = ignore errors,  1 = log errors and continue, 2 = (re)raise errors (1)
-        :param int protfilter: (kwarg) protocol filter 1 = NMEA, 2 = UBX, 3 = BOTH (3)
+        :param int protfilter: (kwarg) protocol filter 1 = NMEA, 2 = UBX, 4 = RTCM3 (3)
         :param int validate: (kwarg) 0 = ignore invalid checksum, 1 = validate checksum (1)
         :param int msgmode: (kwarg) 0=GET, 1=SET, 2=POLL (0)
         :param bool parsebitfield: (kwarg) 1 = parse bitfields, 0 = leave as bytes (1)
@@ -48,7 +50,6 @@ class UBXReader:
             kwargs.get("protfilter", ubt.NMEA_PROTOCOL | ubt.UBX_PROTOCOL)
         )
         self._quitonerror = int(kwargs.get("quitonerror", ubt.ERR_LOG))
-        # self._ubxonly = kwargs.get("ubxonly", False) # flag superceded by protfilter
         self._validate = int(kwargs.get("validate", ubt.VALCKSUM))
         self._parsebf = int(kwargs.get("parsebitfield", True))
         self._msgmode = int(kwargs.get("msgmode", 0))
@@ -97,18 +98,15 @@ class UBXReader:
             while parsing:  # loop until end of valid message or EOF
                 raw_data = None
                 parsed_data = None
-                byte1 = self._stream.read(1)  # read the first byte
-                if len(byte1) < 1:
-                    raise EOFError()
-                # if not UBX or NMEA, discard and continue
-                if byte1 not in (b"\xb5", b"\x24"):
+                byte1 = self._read_bytes(1)  # read the first byte
+                # if not UBX, NMEA or RTCM3, discard and continue
+                if byte1 not in (b"\xb5", b"\x24", b"\xd3"):
                     continue
-                byte2 = self._stream.read(1)
-                if len(byte2) < 1:
-                    raise EOFError()
+                byte2 = self._read_bytes(1)
+                bytehdr = byte1 + byte2
                 # if it's a UBX message (b'\xb5\x62')
-                if byte1 + byte2 == ubt.UBX_HDR:
-                    (raw_data, parsed_data) = self._parse_ubx(byte1 + byte2)
+                if bytehdr == ubt.UBX_HDR:
+                    (raw_data, parsed_data) = self._parse_ubx(bytehdr)
                     # if protocol filter passes UBX, return message,
                     # otherwise discard and continue
                     if self._protfilter & ubt.UBX_PROTOCOL:
@@ -116,19 +114,32 @@ class UBXReader:
                     else:
                         continue
                 # if it's an NMEA message ('$G' or '$P')
-                elif byte1 + byte2 in ubt.NMEA_HDR:
-                    (raw_data, parsed_data) = self._parse_nmea(byte1 + byte2)
+                elif bytehdr in ubt.NMEA_HDR:
+                    (raw_data, parsed_data) = self._parse_nmea(bytehdr)
                     # if protocol filter passes NMEA, return message,
                     # otherwise discard and continue
                     if self._protfilter & ubt.NMEA_PROTOCOL:
                         parsing = False
                     else:
                         continue
+                # if it's a RTCM3 message
+                # (byte1 = 0xd3; byte2 = 0b000000**)
+                elif byte1 == b"\xd3" and (byte2[0] & ~0x03) == 0:
+                    (raw_data, parsed_data) = self._parse_rtcm3(bytehdr)
+                    # if protocol filter passes RTCM, return message,
+                    # otherwise discard and continue
+                    if self._protfilter & ubt.RTCM3_PROTOCOL:
+                        parsing = False
+                    else:
+                        continue
                 # unrecognised protocol header
                 else:
-                    if self._quitonerror != ubt.ERR_IGNORE:
-                        raise ube.UBXStreamError(f"Unknown protocol {byte1 + byte2}.")
-                    return (None, None)
+                    if self._quitonerror == ubt.ERR_RAISE:
+                        raise ube.UBXStreamError(f"Unknown protocol {bytehdr}.")
+                    elif self._quitonerror == ubt.ERR_LOG:
+                        return (bytehdr, f"<UNKNOWN PROTOCOL(header={bytehdr})>")
+                    else:  # ignore unknown protocol and continue
+                        continue
 
         except EOFError:
             return (None, None)
@@ -145,16 +156,12 @@ class UBXReader:
         """
 
         # read the rest of the UBX message from the buffer
-        byten = self._stream.read(4)
-        if len(byten) < 4:  # EOF
-            raise EOFError()
+        byten = self._read_bytes(4)
         clsid = byten[0:1]
         msgid = byten[1:2]
         lenb = byten[2:4]
         leni = int.from_bytes(lenb, "little", signed=False)
-        byten = self._stream.read(leni + 2)
-        if len(byten) < leni + 2:  # EOF
-            raise EOFError()
+        byten = self._read_bytes(leni + 2)
         plb = byten[0:leni]
         cksum = byten[leni : leni + 2]
         raw_data = hdr + clsid + msgid + lenb + plb + cksum
@@ -196,11 +203,48 @@ class UBXReader:
             parsed_data = None
         return (raw_data, parsed_data)
 
+    def _parse_rtcm3(self, hdr: bytes, **kwargs) -> tuple:
+        """
+        Parse any RTCM3 data in the stream.
+        NB: pyubx2 does not decode RTCM3 data; the
+        RTCMMessage object is simply a stub.
+
+        :param bytes hdr: first 2 bytes of RTCM3 header
+        :param bool validate: (kwarg) validate crc Y/N
+        :return: tuple of (raw_data as bytes, parsed_stub as RTCMMessage)
+        :rtype: tuple
+        """
+
+        hdr3 = self._read_bytes(1)
+        size = hdr3[0] | (hdr[1] << 8)
+        payload = self._read_bytes(size)
+        crc = self._read_bytes(3)
+        raw_data = hdr + hdr3 + payload + crc
+        if self._validate & ubt.VALCKSUM:
+            if calc_crc24q(raw_data):
+                raise ube.UBXParseError(f"RTCM3 message invalid - failed CRC: {crc}")
+        parsed_data = RTCMMessage(payload)
+        return (raw_data, parsed_data)
+
+    def _read_bytes(self, size: int) -> bytes:
+        """
+        Read a specified number of bytes from stream.
+
+        :param int size: number of bytes to read
+        :return: bytes
+        :raises: EOFError if stream ends prematurely
+        """
+
+        data = self._stream.read(size)
+        if len(data) < size:  # EOF
+            raise EOFError()
+        return data
+
     def iterate(self, **kwargs) -> tuple:
         """
         Invoke the iterator within an exception handling framework.
 
-        :param int quitonerror: (kwarg) 0 = ignore errors,  1 = log errors and continue, 2 = (re)raise errors (0)
+        :param int quitonerror: (kwarg) 0 = ignore errors,  1 = log errors and continue, 2 = (re)raise errors (1)
         :param object errorhandler: (kwarg) Optional error handler (None)
         :return: tuple of (raw_data as bytes, parsed_data as UBXMessage or NMEAMessage)
         :rtype: tuple
@@ -208,7 +252,7 @@ class UBXReader:
 
         """
 
-        quitonerror = kwargs.get("quitonerror", ubt.ERR_IGNORE)
+        quitonerror = kwargs.get("quitonerror", self._quitonerror)
         errorhandler = kwargs.get("errorhandler", None)
 
         while True:
