@@ -96,13 +96,13 @@ UBX_CONFIG_DATABASE = {
     "CFG_GEOFENCE_USE_FENCE3": (0x10240040, L),
     "CFG_GEOFENCE_USE_FENCE4": (0x10240050, L),
     "CFG_GEOFENCE_USE_PIO": (0x10240012, L),
-    "CFG_HW_ANT_CFG_OPENDET_POL": (0x10A30032, L),
     "CFG_HW_ANT_CFG_OPENDET": (0x10A30031, L),
-    "CFG_HW_ANT_CFG_PWRDOWN_POL": (0x10A30034, L),
+    "CFG_HW_ANT_CFG_OPENDET_POL": (0x10A30032, L),
     "CFG_HW_ANT_CFG_PWRDOWN": (0x10A30033, L),
+    "CFG_HW_ANT_CFG_PWRDOWN_POL": (0x10A30034, L),
     "CFG_HW_ANT_CFG_RECOVER": (0x10A30035, L),
-    "CFG_HW_ANT_CFG_SHORTDET_POL": (0x10A30030, L),
     "CFG_HW_ANT_CFG_SHORTDET": (0x10A3002F, L),
+    "CFG_HW_ANT_CFG_SHORTDET_POL": (0x10A30030, L),
     "CFG_HW_ANT_CFG_VOLTCTRL": (0x10A3002E, L),
     "CFG_HW_ANT_SUP_ENGINE": (0x20A30054, E1),
     "CFG_HW_ANT_SUP_OPEN_PIN": (0x20A30038, U1),
@@ -116,7 +116,9 @@ UBX_CONFIG_DATABASE = {
     "CFG_I2C_EXTENDEDTIMEOUT": (0x10510002, L),
     "CFG_I2C_REMAP": (0x10510004, L),
     "CFG_I2CINPROT_NMEA": (0x10710002, L),
+    "CFG_I2CINPROT_RTCM2X": (0x10710003, L),
     "CFG_I2CINPROT_RTCM3X": (0x10710004, L),
+    "CFG_I2CINPROT_SPARTN": (0x10710005, L),
     "CFG_I2CINPROT_UBX": (0x10710001, L),
     "CFG_I2COUTPROT_NMEA": (0x10720002, L),
     "CFG_I2COUTPROT_RTCM3X": (0x10720004, L),
@@ -134,8 +136,8 @@ UBX_CONFIG_DATABASE = {
     "CFG_ITFM_ANTSETTING": (0x20410010, E1),
     "CFG_ITFM_BBTHRESHOLD": (0x20410001, U1),
     "CFG_ITFM_CWTHRESHOLD": (0x20410002, U1),
-    "CFG_ITFM_ENABLE_AUX": (0x10410013, L),
     "CFG_ITFM_ENABLE": (0x1041000D, L),
+    "CFG_ITFM_ENABLE_AUX": (0x10410013, L),
     "CFG_LOGFILTER_APPLY_ALL_FILTERS": (0x10DE0004, L),
     "CFG_LOGFILTER_MIN_INTERVAL": (0x30DE0005, U2),
     "CFG_LOGFILTER_ONCE_PER_WAKE_UP_ENA": (0x10DE0003, L),
@@ -270,11 +272,41 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_PUBX_ID_POLYT_UART1": (0x209100F7, U1),
     "CFG_MSGOUT_PUBX_ID_POLYT_UART2": (0x209100F8, U1),
     "CFG_MSGOUT_PUBX_ID_POLYT_USB": (0x209100F9, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1001_I2C": (0x209102A9, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1001_SPI": (0x209102AD, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1001_UART1": (0x209102AA, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1001_UART2": (0x209102AB, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1001_USB": (0x209102AC, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1002_I2C": (0x209102B3, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1002_SPI": (0x209102B7, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1002_UART1": (0x209102B4, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1002_UART2": (0x209102B5, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1002_USB": (0x209102B6, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1005_I2C": (0x209102BD, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1005_SPI": (0x209102C1, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1005_UART1": (0x209102BE, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1005_UART2": (0x209102BF, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1005_USB": (0x209102C0, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1006_I2C": (0x209102C2, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1006_SPI": (0x209102C6, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1006_UART1": (0x209102C3, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1006_UART2": (0x209102C4, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1006_USB": (0x209102C5, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1007_I2C": (0x209102C7, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1007_SPI": (0x209102CB, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1007_UART1": (0x209102C8, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1007_UART2": (0x209102C9, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1007_USB": (0x209102CA, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1009_I2C": (0x209102AE, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1009_SPI": (0x209102B2, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1009_UART1": (0x209102AF, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1009_UART2": (0x209102B0, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1009_USB": (0x209102B1, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1010_I2C": (0x209102B8, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1010_SPI": (0x209102BC, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1010_UART1": (0x209102B9, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1010_UART2": (0x209102BA, U1),
+    "CFG_MSGOUT_RTCM_3X_TYPE1010_USB": (0x209102BB, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1074_I2C": (0x2091035E, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1074_SPI": (0x20910362, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE1074_UART1": (0x2091035F, U1),
@@ -330,8 +362,31 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_RTCM_3X_TYPE4072_1_UART1": (0x20910382, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE4072_1_UART2": (0x20910383, U1),
     "CFG_MSGOUT_RTCM_3X_TYPE4072_1_USB": (0x20910384, U1),
-    "CFG_MSGOUT_UBX_0x20910119": (0x20910119, U1),
-    "CFG_MSGOUT_UBX_0x2091011A": (0x2091011A, U1),
+    "CFG_MSGOUT_UBX_AID_ALM_I2C": (0x2091016E, U1),
+    "CFG_MSGOUT_UBX_AID_ALM_SPI": (0x20910172, U1),
+    "CFG_MSGOUT_UBX_AID_ALM_UART1": (0x2091016F, U1),
+    "CFG_MSGOUT_UBX_AID_ALM_UART2": (0x20910170, U1),
+    "CFG_MSGOUT_UBX_AID_ALM_USB": (0x20910171, U1),
+    "CFG_MSGOUT_UBX_AID_AOP_I2C": (0x2091026D, U1),
+    "CFG_MSGOUT_UBX_AID_AOP_SPI": (0x20910271, U1),
+    "CFG_MSGOUT_UBX_AID_AOP_UART1": (0x2091026E, U1),
+    "CFG_MSGOUT_UBX_AID_AOP_UART2": (0x2091026F, U1),
+    "CFG_MSGOUT_UBX_AID_AOP_USB": (0x20910270, U1),
+    "CFG_MSGOUT_UBX_AID_EPH_I2C": (0x20910164, U1),
+    "CFG_MSGOUT_UBX_AID_EPH_SPI": (0x20910168, U1),
+    "CFG_MSGOUT_UBX_AID_EPH_UART1": (0x20910165, U1),
+    "CFG_MSGOUT_UBX_AID_EPH_UART2": (0x20910166, U1),
+    "CFG_MSGOUT_UBX_AID_EPH_USB": (0x20910167, U1),
+    "CFG_MSGOUT_UBX_AID_INI_I2C": (0x209100FB, U1),
+    "CFG_MSGOUT_UBX_AID_INI_SPI": (0x209100FF, U1),
+    "CFG_MSGOUT_UBX_AID_INI_UART1": (0x209100FC, U1),
+    "CFG_MSGOUT_UBX_AID_INI_UART2": (0x209100FD, U1),
+    "CFG_MSGOUT_UBX_AID_INI_USB": (0x209100FE, U1),
+    "CFG_MSGOUT_UBX_DBG_31_I2C": (0x20910119, U1),
+    "CFG_MSGOUT_UBX_DBG_31_SPI": (0x2091011D, U1),
+    "CFG_MSGOUT_UBX_DBG_31_UART1": (0x2091011A, U1),
+    "CFG_MSGOUT_UBX_DBG_31_UART2": (0x2091011B, U1),
+    "CFG_MSGOUT_UBX_DBG_31_USB": (0x2091011C, U1),
     "CFG_MSGOUT_UBX_ESF_ALG_I2C": (0x2091010F, U1),
     "CFG_MSGOUT_UBX_ESF_ALG_SPI": (0x20910113, U1),
     "CFG_MSGOUT_UBX_ESF_ALG_UART1": (0x20910110, U1),
@@ -357,6 +412,21 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_ESF_STATUS_UART1": (0x20910106, U1),
     "CFG_MSGOUT_UBX_ESF_STATUS_UART2": (0x20910107, U1),
     "CFG_MSGOUT_UBX_ESF_STATUS_USB": (0x20910108, U1),
+    "CFG_MSGOUT_UBX_HNR_ATT_I2C": (0x20910377, U1),
+    "CFG_MSGOUT_UBX_HNR_ATT_SPI": (0x2091037B, U1),
+    "CFG_MSGOUT_UBX_HNR_ATT_UART1": (0x20910378, U1),
+    "CFG_MSGOUT_UBX_HNR_ATT_UART2": (0x20910379, U1),
+    "CFG_MSGOUT_UBX_HNR_ATT_USB": (0x2091037A, U1),
+    "CFG_MSGOUT_UBX_HNR_INS_I2C": (0x20910372, U1),
+    "CFG_MSGOUT_UBX_HNR_INS_SPI": (0x20910376, U1),
+    "CFG_MSGOUT_UBX_HNR_INS_UART1": (0x20910373, U1),
+    "CFG_MSGOUT_UBX_HNR_INS_UART2": (0x20910374, U1),
+    "CFG_MSGOUT_UBX_HNR_INS_USB": (0x20910375, U1),
+    "CFG_MSGOUT_UBX_HNR_PVT_I2C": (0x2091028B, U1),
+    "CFG_MSGOUT_UBX_HNR_PVT_SPI": (0x2091028F, U1),
+    "CFG_MSGOUT_UBX_HNR_PVT_UART1": (0x2091028C, U1),
+    "CFG_MSGOUT_UBX_HNR_PVT_UART2": (0x2091028D, U1),
+    "CFG_MSGOUT_UBX_HNR_PVT_USB": (0x2091028E, U1),
     "CFG_MSGOUT_UBX_LOG_INFO_I2C": (0x20910259, U1),
     "CFG_MSGOUT_UBX_LOG_INFO_SPI": (0x2091025D, U1),
     "CFG_MSGOUT_UBX_LOG_INFO_UART1": (0x2091025A, U1),
@@ -412,6 +482,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_MON_SPAN_UART1": (0x2091038C, U1),
     "CFG_MSGOUT_UBX_MON_SPAN_UART2": (0x2091038D, U1),
     "CFG_MSGOUT_UBX_MON_SPAN_USB": (0x2091038E, U1),
+    "CFG_MSGOUT_UBX_MON_SYS_I2C": (0x2091069D, U1),
+    "CFG_MSGOUT_UBX_MON_SYS_SPI": (0x209106A1, U1),
+    "CFG_MSGOUT_UBX_MON_SYS_UART1": (0x2091069E, U1),
+    "CFG_MSGOUT_UBX_MON_SYS_UART2": (0x2091069F, U1),
+    "CFG_MSGOUT_UBX_MON_SYS_USB": (0x209106A0, U1),
     "CFG_MSGOUT_UBX_MON_TXBUF_I2C": (0x2091019B, U1),
     "CFG_MSGOUT_UBX_MON_TXBUF_SPI": (0x2091019F, U1),
     "CFG_MSGOUT_UBX_MON_TXBUF_UART1": (0x2091019C, U1),
@@ -437,6 +512,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV_COV_UART1": (0x20910084, U1),
     "CFG_MSGOUT_UBX_NAV_COV_UART2": (0x20910085, U1),
     "CFG_MSGOUT_UBX_NAV_COV_USB": (0x20910086, U1),
+    "CFG_MSGOUT_UBX_NAV_DGPS_I2C": (0x20910074, U1),
+    "CFG_MSGOUT_UBX_NAV_DGPS_SPI": (0x20910078, U1),
+    "CFG_MSGOUT_UBX_NAV_DGPS_UART1": (0x20910075, U1),
+    "CFG_MSGOUT_UBX_NAV_DGPS_UART2": (0x20910076, U1),
+    "CFG_MSGOUT_UBX_NAV_DGPS_USB": (0x20910077, U1),
     "CFG_MSGOUT_UBX_NAV_DOP_I2C": (0x20910038, U1),
     "CFG_MSGOUT_UBX_NAV_DOP_SPI": (0x2091003C, U1),
     "CFG_MSGOUT_UBX_NAV_DOP_UART1": (0x20910039, U1),
@@ -482,6 +562,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV_ORB_UART1": (0x20910011, U1),
     "CFG_MSGOUT_UBX_NAV_ORB_UART2": (0x20910012, U1),
     "CFG_MSGOUT_UBX_NAV_ORB_USB": (0x20910013, U1),
+    "CFG_MSGOUT_UBX_NAV_PL_I2C": (0x20910415, U1),
+    "CFG_MSGOUT_UBX_NAV_PL_SPI": (0x20910419, U1),
+    "CFG_MSGOUT_UBX_NAV_PL_UART1": (0x20910416, U1),
+    "CFG_MSGOUT_UBX_NAV_PL_UART2": (0x20910417, U1),
+    "CFG_MSGOUT_UBX_NAV_PL_USB": (0x20910418, U1),
     "CFG_MSGOUT_UBX_NAV_POSECEF_I2C": (0x20910024, U1),
     "CFG_MSGOUT_UBX_NAV_POSECEF_SPI": (0x20910028, U1),
     "CFG_MSGOUT_UBX_NAV_POSECEF_UART1": (0x20910025, U1),
@@ -492,6 +577,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV_POSLLH_UART1": (0x2091002A, U1),
     "CFG_MSGOUT_UBX_NAV_POSLLH_UART2": (0x2091002B, U1),
     "CFG_MSGOUT_UBX_NAV_POSLLH_USB": (0x2091002C, U1),
+    "CFG_MSGOUT_UBX_NAV_PVAT_I2C": (0x2091062A, U1),
+    "CFG_MSGOUT_UBX_NAV_PVAT_SPI": (0x2091062E, U1),
+    "CFG_MSGOUT_UBX_NAV_PVAT_UART1": (0x2091062B, U1),
+    "CFG_MSGOUT_UBX_NAV_PVAT_UART2": (0x2091062C, U1),
+    "CFG_MSGOUT_UBX_NAV_PVAT_USB": (0x2091062D, U1),
     "CFG_MSGOUT_UBX_NAV_PVT_I2C": (0x20910006, U1),
     "CFG_MSGOUT_UBX_NAV_PVT_SPI": (0x2091000A, U1),
     "CFG_MSGOUT_UBX_NAV_PVT_UART1": (0x20910007, U1),
@@ -522,6 +612,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV_SLAS_UART1": (0x20910337, U1),
     "CFG_MSGOUT_UBX_NAV_SLAS_UART2": (0x20910338, U1),
     "CFG_MSGOUT_UBX_NAV_SLAS_USB": (0x20910339, U1),
+    "CFG_MSGOUT_UBX_NAV_SOL_I2C": (0x20910001, U1),
+    "CFG_MSGOUT_UBX_NAV_SOL_SPI": (0x20910005, U1),
+    "CFG_MSGOUT_UBX_NAV_SOL_UART1": (0x20910002, U1),
+    "CFG_MSGOUT_UBX_NAV_SOL_UART2": (0x20910003, U1),
+    "CFG_MSGOUT_UBX_NAV_SOL_USB": (0x20910004, U1),
     "CFG_MSGOUT_UBX_NAV_STATUS_I2C": (0x2091001A, U1),
     "CFG_MSGOUT_UBX_NAV_STATUS_SPI": (0x2091001E, U1),
     "CFG_MSGOUT_UBX_NAV_STATUS_UART1": (0x2091001B, U1),
@@ -532,6 +627,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV_SVIN_UART1": (0x20910089, U1),
     "CFG_MSGOUT_UBX_NAV_SVIN_UART2": (0x2091008A, U1),
     "CFG_MSGOUT_UBX_NAV_SVIN_USB": (0x2091008B, U1),
+    "CFG_MSGOUT_UBX_NAV_SVINFO_I2C": (0x2091000B, U1),
+    "CFG_MSGOUT_UBX_NAV_SVINFO_SPI": (0x2091000F, U1),
+    "CFG_MSGOUT_UBX_NAV_SVINFO_UART1": (0x2091000C, U1),
+    "CFG_MSGOUT_UBX_NAV_SVINFO_UART2": (0x2091000D, U1),
+    "CFG_MSGOUT_UBX_NAV_SVINFO_USB": (0x2091000E, U1),
     "CFG_MSGOUT_UBX_NAV_TIMEBDS_I2C": (0x20910051, U1),
     "CFG_MSGOUT_UBX_NAV_TIMEBDS_SPI": (0x20910055, U1),
     "CFG_MSGOUT_UBX_NAV_TIMEBDS_UART1": (0x20910052, U1),
@@ -592,6 +692,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV2_DOP_UART1": (0x20910466, U1),
     "CFG_MSGOUT_UBX_NAV2_DOP_UART2": (0x20910467, U1),
     "CFG_MSGOUT_UBX_NAV2_DOP_USB": (0x20910468, U1),
+    "CFG_MSGOUT_UBX_NAV2_EELL_I2C": (0x20910470, U1),
+    "CFG_MSGOUT_UBX_NAV2_EELL_SPI": (0x20910474, U1),
+    "CFG_MSGOUT_UBX_NAV2_EELL_UART1": (0x20910471, U1),
+    "CFG_MSGOUT_UBX_NAV2_EELL_UART2": (0x20910472, U1),
+    "CFG_MSGOUT_UBX_NAV2_EELL_USB": (0x20910473, U1),
     "CFG_MSGOUT_UBX_NAV2_EOE_I2C": (0x20910565, U1),
     "CFG_MSGOUT_UBX_NAV2_EOE_SPI": (0x20910569, U1),
     "CFG_MSGOUT_UBX_NAV2_EOE_UART1": (0x20910566, U1),
@@ -612,6 +717,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV2_POSLLH_UART1": (0x20910486, U1),
     "CFG_MSGOUT_UBX_NAV2_POSLLH_UART2": (0x20910487, U1),
     "CFG_MSGOUT_UBX_NAV2_POSLLH_USB": (0x20910488, U1),
+    "CFG_MSGOUT_UBX_NAV2_PVAT_I2C": (0x2091062F, U1),
+    "CFG_MSGOUT_UBX_NAV2_PVAT_SPI": (0x20910633, U1),
+    "CFG_MSGOUT_UBX_NAV2_PVAT_UART1": (0x20910630, U1),
+    "CFG_MSGOUT_UBX_NAV2_PVAT_UART2": (0x20910631, U1),
+    "CFG_MSGOUT_UBX_NAV2_PVAT_USB": (0x20910632, U1),
     "CFG_MSGOUT_UBX_NAV2_PVT_I2C": (0x20910490, U1),
     "CFG_MSGOUT_UBX_NAV2_PVT_SPI": (0x20910494, U1),
     "CFG_MSGOUT_UBX_NAV2_PVT_UART1": (0x20910491, U1),
@@ -632,11 +742,21 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV2_SIG_UART1": (0x20910506, U1),
     "CFG_MSGOUT_UBX_NAV2_SIG_UART2": (0x20910507, U1),
     "CFG_MSGOUT_UBX_NAV2_SIG_USB": (0x20910508, U1),
+    "CFG_MSGOUT_UBX_NAV2_SLAS_I2C": (0x20910510, U1),
+    "CFG_MSGOUT_UBX_NAV2_SLAS_SPI": (0x20910514, U1),
+    "CFG_MSGOUT_UBX_NAV2_SLAS_UART1": (0x20910511, U1),
+    "CFG_MSGOUT_UBX_NAV2_SLAS_UART2": (0x20910512, U1),
+    "CFG_MSGOUT_UBX_NAV2_SLAS_USB": (0x20910513, U1),
     "CFG_MSGOUT_UBX_NAV2_STATUS_I2C": (0x20910515, U1),
     "CFG_MSGOUT_UBX_NAV2_STATUS_SPI": (0x20910519, U1),
     "CFG_MSGOUT_UBX_NAV2_STATUS_UART1": (0x20910516, U1),
     "CFG_MSGOUT_UBX_NAV2_STATUS_UART2": (0x20910517, U1),
     "CFG_MSGOUT_UBX_NAV2_STATUS_USB": (0x20910518, U1),
+    "CFG_MSGOUT_UBX_NAV2_SVIN_I2C": (0x20910520, U1),
+    "CFG_MSGOUT_UBX_NAV2_SVIN_SPI": (0x20910524, U1),
+    "CFG_MSGOUT_UBX_NAV2_SVIN_UART1": (0x20910521, U1),
+    "CFG_MSGOUT_UBX_NAV2_SVIN_UART2": (0x20910522, U1),
+    "CFG_MSGOUT_UBX_NAV2_SVIN_USB": (0x20910523, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEBDS_I2C": (0x20910525, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEBDS_SPI": (0x20910529, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEBDS_UART1": (0x20910526, U1),
@@ -662,6 +782,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV2_TIMELS_UART1": (0x20910546, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMELS_UART2": (0x20910547, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMELS_USB": (0x20910548, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_I2C": (0x20910575, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_SPI": (0x20910579, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_UART1": (0x20910576, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_UART2": (0x20910577, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_USB": (0x20910578, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEUTC_I2C": (0x20910550, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEUTC_SPI": (0x20910554, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEUTC_UART1": (0x20910551, U1),
@@ -677,6 +802,26 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV2_VELNED_UART1": (0x20910561, U1),
     "CFG_MSGOUT_UBX_NAV2_VELNED_UART2": (0x20910562, U1),
     "CFG_MSGOUT_UBX_NAV2_VELNED_USB": (0x20910563, U1),
+    "CFG_MSGOUT_UBX_RXM_ALM_I2C": (0x20910173, U1),
+    "CFG_MSGOUT_UBX_RXM_ALM_SPI": (0x20910177, U1),
+    "CFG_MSGOUT_UBX_RXM_ALM_UART1": (0x20910174, U1),
+    "CFG_MSGOUT_UBX_RXM_ALM_UART2": (0x20910175, U1),
+    "CFG_MSGOUT_UBX_RXM_ALM_USB": (0x20910176, U1),
+    "CFG_MSGOUT_UBX_RXM_COR_I2C": (0x209106B6, U1),
+    "CFG_MSGOUT_UBX_RXM_COR_SPI": (0x209106BA, U1),
+    "CFG_MSGOUT_UBX_RXM_COR_UART1": (0x209106B7, U1),
+    "CFG_MSGOUT_UBX_RXM_COR_UART2": (0x209106B8, U1),
+    "CFG_MSGOUT_UBX_RXM_COR_USB": (0x209106B9, U1),
+    "CFG_MSGOUT_UBX_RXM_EPH_I2C": (0x20910169, U1),
+    "CFG_MSGOUT_UBX_RXM_EPH_SPI": (0x2091016D, U1),
+    "CFG_MSGOUT_UBX_RXM_EPH_UART1": (0x2091016A, U1),
+    "CFG_MSGOUT_UBX_RXM_EPH_UART2": (0x2091016B, U1),
+    "CFG_MSGOUT_UBX_RXM_EPH_USB": (0x2091016C, U1),
+    "CFG_MSGOUT_UBX_RXM_IMES_I2C": (0x2091015A, U1),
+    "CFG_MSGOUT_UBX_RXM_IMES_SPI": (0x2091015E, U1),
+    "CFG_MSGOUT_UBX_RXM_IMES_UART1": (0x2091015B, U1),
+    "CFG_MSGOUT_UBX_RXM_IMES_UART2": (0x2091015C, U1),
+    "CFG_MSGOUT_UBX_RXM_IMES_USB": (0x2091015D, U1),
     "CFG_MSGOUT_UBX_RXM_MEASX_I2C": (0x20910204, U1),
     "CFG_MSGOUT_UBX_RXM_MEASX_SPI": (0x20910208, U1),
     "CFG_MSGOUT_UBX_RXM_MEASX_UART1": (0x20910205, U1),
@@ -687,6 +832,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_RXM_PMP_UART1": (0x2091031E, U1),
     "CFG_MSGOUT_UBX_RXM_PMP_UART2": (0x2091031F, U1),
     "CFG_MSGOUT_UBX_RXM_PMP_USB": (0x20910320, U1),
+    "CFG_MSGOUT_UBX_RXM_QZSSL6_I2C": (0x2091033F, U1),
+    "CFG_MSGOUT_UBX_RXM_QZSSL6_SPI": (0x20910343, U1),
+    "CFG_MSGOUT_UBX_RXM_QZSSL6_UART1": (0x20910340, U1),
+    "CFG_MSGOUT_UBX_RXM_QZSSL6_UART2": (0x20910341, U1),
+    "CFG_MSGOUT_UBX_RXM_QZSSL6_USB": (0x20910342, U1),
     "CFG_MSGOUT_UBX_RXM_RAWX_I2C": (0x209102A4, U1),
     "CFG_MSGOUT_UBX_RXM_RAWX_SPI": (0x209102A8, U1),
     "CFG_MSGOUT_UBX_RXM_RAWX_UART1": (0x209102A5, U1),
@@ -707,11 +857,26 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_RXM_SFRBX_UART1": (0x20910232, U1),
     "CFG_MSGOUT_UBX_RXM_SFRBX_UART2": (0x20910233, U1),
     "CFG_MSGOUT_UBX_RXM_SFRBX_USB": (0x20910234, U1),
+    "CFG_MSGOUT_UBX_RXM_SPARTN_I2C": (0x20910605, U1),
+    "CFG_MSGOUT_UBX_RXM_SPARTN_SPI": (0x20910609, U1),
+    "CFG_MSGOUT_UBX_RXM_SPARTN_UART1": (0x20910606, U1),
+    "CFG_MSGOUT_UBX_RXM_SPARTN_UART2": (0x20910607, U1),
+    "CFG_MSGOUT_UBX_RXM_SPARTN_USB": (0x20910608, U1),
+    "CFG_MSGOUT_UBX_RXM_SVSI_I2C": (0x20910150, U1),
+    "CFG_MSGOUT_UBX_RXM_SVSI_SPI": (0x20910154, U1),
+    "CFG_MSGOUT_UBX_RXM_SVSI_UART1": (0x20910151, U1),
+    "CFG_MSGOUT_UBX_RXM_SVSI_UART2": (0x20910152, U1),
+    "CFG_MSGOUT_UBX_RXM_SVSI_USB": (0x20910153, U1),
     "CFG_MSGOUT_UBX_RXM_TM_I2C": (0x20910610, U1),
     "CFG_MSGOUT_UBX_RXM_TM_SPI": (0x20910614, U1),
     "CFG_MSGOUT_UBX_RXM_TM_UART1": (0x20910611, U1),
     "CFG_MSGOUT_UBX_RXM_TM_UART2": (0x20910612, U1),
     "CFG_MSGOUT_UBX_RXM_TM_USB": (0x20910613, U1),
+    "CFG_MSGOUT_UBX_SEC_ECSIGN_I2C": (0x2091034A, U1),
+    "CFG_MSGOUT_UBX_SEC_ECSIGN_SPI": (0x2091034E, U1),
+    "CFG_MSGOUT_UBX_SEC_ECSIGN_UART1": (0x2091034B, U1),
+    "CFG_MSGOUT_UBX_SEC_ECSIGN_UART2": (0x2091034C, U1),
+    "CFG_MSGOUT_UBX_SEC_ECSIGN_USB": (0x2091034D, U1),
     "CFG_MSGOUT_UBX_SEC_SIG_I2C": (0x20910634, U1),
     "CFG_MSGOUT_UBX_SEC_SIG_SPI": (0x20910638, U1),
     "CFG_MSGOUT_UBX_SEC_SIG_UART1": (0x20910635, U1),
@@ -749,6 +914,7 @@ UBX_CONFIG_DATABASE = {
     "CFG_NAVSPG_CONSTR_ALT": (0x401100C1, I4),
     "CFG_NAVSPG_CONSTR_ALTVAR": (0x401100C2, U4),
     "CFG_NAVSPG_CONSTR_DGNSSTO": (0x201100C4, U1),
+    "CFG_NAVSPG_CONSTR_PROPLIMIT": (0x401100C3, U4),
     "CFG_NAVSPG_DYNMODEL": (0x20110021, E1),
     "CFG_NAVSPG_FIXMODE": (0x20110011, E1),
     "CFG_NAVSPG_INFIL_CNOTHRS": (0x201100AB, U1),
@@ -763,6 +929,7 @@ UBX_CONFIG_DATABASE = {
     "CFG_NAVSPG_OUTFIL_PDOP": (0x301100B1, U2),
     "CFG_NAVSPG_OUTFIL_TACC": (0x301100B4, U2),
     "CFG_NAVSPG_OUTFIL_TDOP": (0x301100B2, U2),
+    "CFG_NAVSPG_PL_ENA": (0x101100D7, L),
     "CFG_NAVSPG_SIGATTCOMP": (0x201100D6, E1),
     "CFG_NAVSPG_USE_PPP": (0x10110019, L),
     "CFG_NAVSPG_USE_USRDAT": (0x10110061, L),
@@ -858,6 +1025,7 @@ UBX_CONFIG_DATABASE = {
     "CFG_SEC_CFG_LOCK_UNLOCKGRP1": (0x30F6000A, U2),
     "CFG_SEC_CFG_LOCK_UNLOCKGRP2": (0x30F6000B, U2),
     "CFG_SEC_CFG_LOCK": (0x10F60009, L),
+    "CFG_SFCORE_HNR_RATE": (0x2008001A, U1),
     "CFG_SFCORE_USE_SF": (0x10080001, L),
     "CFG_SFIMU_ACCEL_ACCURACY": (0x30060018, U2),
     "CFG_SFIMU_ACCEL_FREQUENCY": (0x20060016, U1),
@@ -906,6 +1074,8 @@ UBX_CONFIG_DATABASE = {
     "CFG_SIGNAL_GPS_L1CA_ENA": (0x10310001, L),
     "CFG_SIGNAL_GPS_L2C_ENA": (0x10310003, L),
     "CFG_SIGNAL_GPS_L5_ENA": (0x10310004, L),
+    "CFG_SIGNAL_IMES_ENA": (0x10310023, L),
+    "CFG_SIGNAL_IMES_L1_ENA": (0x10310011, L),
     "CFG_SIGNAL_QZSS_ENA": (0x10310024, L),
     "CFG_SIGNAL_QZSS_L1CA_ENA": (0x10310012, L),
     "CFG_SIGNAL_QZSS_L1S_ENA": (0x10310014, L),
@@ -913,13 +1083,16 @@ UBX_CONFIG_DATABASE = {
     "CFG_SIGNAL_QZSS_L5_ENA": (0x10310017, L),
     "CFG_SIGNAL_SBAS_ENA": (0x10310020, L),
     "CFG_SIGNAL_SBAS_L1CA_ENA": (0x10310005, L),
+    "CFG_SPARTN_USE_SOURCE": (0x20A70001, E1),
     "CFG_SPI_CPHASE": (0x10640003, L),
     "CFG_SPI_CPOLARITY": (0x10640002, L),
     "CFG_SPI_ENABLED": (0x10640006, L),
     "CFG_SPI_EXTENDEDTIMEOUT": (0x10640005, L),
     "CFG_SPI_MAXFF": (0x20640001, U1),
     "CFG_SPIINPROT_NMEA": (0x10790002, L),
+    "CFG_SPIINPROT_RTCM2X": (0x10790003, L),
     "CFG_SPIINPROT_RTCM3X": (0x10790004, L),
+    "CFG_SPIINPROT_SPARTN": (0x10790005, L),
     "CFG_SPIINPROT_UBX": (0x10790001, L),
     "CFG_SPIOUTPROT_NMEA": (0x107A0002, L),
     "CFG_SPIOUTPROT_RTCM3X": (0x107A0004, L),
@@ -943,39 +1116,54 @@ UBX_CONFIG_DATABASE = {
     "CFG_TMODE_SVIN_MIN_DUR": (0x40030010, U4),
     "CFG_TP_ALIGN_TO_TOW_TP1": (0x1005000A, L),
     "CFG_TP_ALIGN_TO_TOW_TP2": (0x10050015, L),
+    "CFG_TP_ALIGN_TO_TOW_TP3": (0x10050020, L),
     "CFG_TP_ANT_CABLEDELAY": (0x30050001, I2),
     "CFG_TP_DRSTR_TP1": (0x20050035, E1),
     "CFG_TP_DRSTR_TP2": (0x20050036, E1),
     "CFG_TP_DUTY_LOCK_TP1": (0x5005002B, R8),
     "CFG_TP_DUTY_LOCK_TP2": (0x5005002D, R8),
+    "CFG_TP_DUTY_LOCK_TP3": (0x5005002F, R8),
     "CFG_TP_DUTY_TP1": (0x5005002A, R8),
     "CFG_TP_DUTY_TP2": (0x5005002C, R8),
+    "CFG_TP_DUTY_TP3": (0x5005002E, R8),
     "CFG_TP_FREQ_LOCK_TP1": (0x40050025, U4),
     "CFG_TP_FREQ_LOCK_TP2": (0x40050027, U4),
+    "CFG_TP_FREQ_LOCK_TP3": (0x40050029, U4),
     "CFG_TP_FREQ_TP1": (0x40050024, U4),
     "CFG_TP_FREQ_TP2": (0x40050026, U4),
+    "CFG_TP_FREQ_TP3": (0x40050028, U4),
     "CFG_TP_LEN_LOCK_TP1": (0x40050005, U4),
     "CFG_TP_LEN_LOCK_TP2": (0x40050010, U4),
+    "CFG_TP_LEN_LOCK_TP3": (0x4005001B, U4),
     "CFG_TP_LEN_TP1": (0x40050004, U4),
     "CFG_TP_LEN_TP2": (0x4005000F, U4),
+    "CFG_TP_LEN_TP3": (0x4005001A, U4),
     "CFG_TP_PERIOD_LOCK_TP1": (0x40050003, U4),
     "CFG_TP_PERIOD_LOCK_TP2": (0x4005000E, U4),
+    "CFG_TP_PERIOD_LOCK_TP3": (0x40050019, U4),
     "CFG_TP_PERIOD_TP1": (0x40050002, U4),
     "CFG_TP_PERIOD_TP2": (0x4005000D, U4),
+    "CFG_TP_PERIOD_TP3": (0x40050018, U4),
     "CFG_TP_POL_TP1": (0x1005000B, L),
     "CFG_TP_POL_TP2": (0x10050016, L),
+    "CFG_TP_POL_TP3": (0x10050021, L),
     "CFG_TP_PULSE_DEF": (0x20050023, E1),
     "CFG_TP_PULSE_LENGTH_DEF": (0x20050030, E1),
     "CFG_TP_SYNC_GNSS_TP1": (0x10050008, L),
     "CFG_TP_SYNC_GNSS_TP2": (0x10050013, L),
+    "CFG_TP_SYNC_GNSS_TP3": (0x1005001E, L),
     "CFG_TP_TIMEGRID_TP1": (0x2005000C, E1),
     "CFG_TP_TIMEGRID_TP2": (0x20050017, E1),
+    "CFG_TP_TIMEGRID_TP3": (0x20050022, E1),
     "CFG_TP_TP1_ENA": (0x10050007, L),
     "CFG_TP_TP2_ENA": (0x10050012, L),
+    "CFG_TP_TP3_ENA": (0x1005001D, L),
     "CFG_TP_USE_LOCKED_TP1": (0x10050009, L),
     "CFG_TP_USE_LOCKED_TP2": (0x10050014, L),
+    "CFG_TP_USE_LOCKED_TP3": (0x1005001F, L),
     "CFG_TP_USER_DELAY_TP1": (0x40050006, I4),
     "CFG_TP_USER_DELAY_TP2": (0x40050011, I4),
+    "CFG_TP_USER_DELAY_TP3": (0x4005001C, I4),
     "CFG_TXREADY_ENABLED": (0x10A20001, L),
     "CFG_TXREADY_INTERFACE": (0x20A20005, E1),
     "CFG_TXREADY_PIN": (0x20A20003, U1),
@@ -985,9 +1173,12 @@ UBX_CONFIG_DATABASE = {
     "CFG_UART1_DATABITS": (0x20520003, E1),
     "CFG_UART1_ENABLED": (0x10520005, L),
     "CFG_UART1_PARITY": (0x20520004, E1),
+    "CFG_UART1_REMAP": (0x10520006, L),
     "CFG_UART1_STOPBITS": (0x20520002, E1),
     "CFG_UART1INPROT_NMEA": (0x10730002, L),
+    "CFG_UART1INPROT_RTCM2X": (0x10730003, L),
     "CFG_UART1INPROT_RTCM3X": (0x10730004, L),
+    "CFG_UART1INPROT_SPARTN": (0x10730005, L),
     "CFG_UART1INPROT_UBX": (0x10730001, L),
     "CFG_UART1OUTPROT_NMEA": (0x10740002, L),
     "CFG_UART1OUTPROT_RTCM3X": (0x10740004, L),
@@ -999,7 +1190,9 @@ UBX_CONFIG_DATABASE = {
     "CFG_UART2_REMAP": (0x10530006, L),
     "CFG_UART2_STOPBITS": (0x20530002, E1),
     "CFG_UART2INPROT_NMEA": (0x10750002, L),
+    "CFG_UART2INPROT_RTCM2X": (0x10750003, L),
     "CFG_UART2INPROT_RTCM3X": (0x10750004, L),
+    "CFG_UART2INPROT_SPARTN": (0x10750005, L),
     "CFG_UART2INPROT_UBX": (0x10750001, L),
     "CFG_UART2OUTPROT_NMEA": (0x10760002, L),
     "CFG_UART2OUTPROT_RTCM3X": (0x10760004, L),
@@ -1022,7 +1215,9 @@ UBX_CONFIG_DATABASE = {
     "CFG_USB_VENDOR_STR2": (0x5065000F, X8),
     "CFG_USB_VENDOR_STR3": (0x50650010, X8),
     "CFG_USBINPROT_NMEA": (0x10770002, L),
+    "CFG_USBINPROT_RTCM2X": (0x10770003, L),
     "CFG_USBINPROT_RTCM3X": (0x10770004, L),
+    "CFG_USBINPROT_SPARTN": (0x10770005, L),
     "CFG_USBINPROT_UBX": (0x10770001, L),
     "CFG_USBOUTPROT_NMEA": (0x10780002, L),
     "CFG_USBOUTPROT_RTCM3X": (0x10780004, L),
