@@ -35,8 +35,9 @@ GNSSDUMP_HELP = (
     + "  Other stream object: gnssdump stream=stream, **kwargs\n"
     + "  Help: gnssdump -h\n\n"
     + f"{GREEN}Optional keyword arguments (default):{NORMAL}\n\n"
-    + "  protfilter - 1 = NMEA, 2 = UBX, 3 = both (3)\n"
+    + "  protfilter - 1 = NMEA, 2 = UBX, 4 = RTCM3 (3 - NMEA & UBX)\n"
     + "  msgfilter - comma-separated list of required message identities e.g. NAV-PVT,GNGSA (None)\n"
+    + "  limit - maximum number of messages to read (0 = unlimited)\n"
     + "  format - output format; 1 = parsed, 2 = binary (raw), 4 = hex, 8 = tabular hex (can be OR'd) (1)\n"
     + "  quitonerror - 0 = ignore errors,  1 = log errors and continue, 2 = (re)raise errors (1)\n"
     + "  validate - 1 = validate message checksum, 0 = ignore invalid checksum (1)\n"
@@ -45,22 +46,9 @@ GNSSDUMP_HELP = (
     + "  verbosity - log message verbosity 0 = low, 1 = medium, 2 = high (1)\n\n"
     + "  nmeahandler - evaluable expression defining external NMEA handler (None)\n"
     + "  ubxhandler - evaluable expression defining external UBX handler (None)\n"
+    + "  rtcmhandler - evaluable expression defining external RTCM3 handler (None)\n"
     + "  errorhandler - evaluable expression defining external error handler (None)\n\n"
     + f"{GREEN}Type Ctrl-C to terminate.{NORMAL}\n\n"
     + f"{YELLOW}© 2022 SEMU Consulting BSD 3-Clause license\n"
     + f"https://github.com/semuconsulting/pyubx2/tree/master#cli{NORMAL}\n\n"
 )
-
-UBXDUMP_HELP = (
-    "\n\nUBXDUMP\n"
-    + "=======\n\n"
-    + "ubxdump is a simple command line utility to stream"
-    + " the parsed UBX output of a u-blox GNSS device to the terminal.\n\n"
-    + "Usage (all args are optional):\n\n"
-    + "  ubxdump port=/dev/ttyACM0 baud=9600 timeout=3 "
-    + "ubxonly=0 validate=1 output=0 parsebitfield=1 "
-    + "filter=*\n\n"
-    + "Type Ctrl-C to terminate.\n\n"
-    + "© 2021 SEMU Consulting BSD 3-Clause license\n"
-    + "https://github.com/semuconsulting/pyubx2/tree/master#cli\n\n"
-)
